@@ -1,15 +1,9 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
-#include "account/abstractaccount.h"
-#include "account/identity.h"
-#include <QAbstractListModel>
-#include <QUrl>
-#include <QUrlQuery>
-#include <QtQml/qqmlregistration.h>
-#include <memory>
+#include "abstractaccount.h"
 
 class AdminAccountInfo;
 
@@ -41,7 +35,6 @@ public:
         IdentityRole = Qt::UserRole + 1,
     };
 
-    // think about delete implementation
     enum AdminAccountAction {
         ApproveAccount,
         RejectAccount,
@@ -93,7 +86,7 @@ public:
 
     int selectedAccountPosition() const;
 
-    // clearing and relaoding the model
+    // clearing and reloading the model
     void clear();
     // delete account data
     Q_INVOKABLE void deleteAccountData(int row);
