@@ -1,9 +1,8 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "admin/federationinfo.h"
+#include "federationinfo.h"
 
-#include <QDateTime>
 #include <QJsonObject>
 
 using namespace Qt::Literals::StringLiterals;
