@@ -2,7 +2,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "networkrequestprogress.h"
-#include <QNetworkReply>
 
 NetworkRequestProgress::NetworkRequestProgress(QObject *parent)
     : QObject(parent)
@@ -56,3 +55,5 @@ void NetworkRequestProgress::setProgress(int progress)
     m_progress = progress;
     Q_EMIT progressChanged();
 }
+
+#include "moc_networkrequestprogress.cpp"
\ No newline at end of file
