@@ -5,8 +5,6 @@
 
 #include "notificationgroupingmodel.h"
 
-#include "notificationmodel.h"
-
 NotificationGroupingModel::NotificationGroupingModel(QObject *parent)
     : QAbstractProxyModel(parent)
 {
@@ -452,3 +450,5 @@ NotificationModel *NotificationGroupingModel::getSourceModel()
 {
     return qobject_cast<NotificationModel *>(sourceModel());
 }
+
+#include "moc_notificationgroupingmodel.cpp"
\ No newline at end of file
