@@ -2,15 +2,10 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "abstracttimelinemodel.h"
-#include "account/abstractaccount.h"
-#include "account/identity.h"
-#include "editor/attachmenteditormodel.h"
-#include "editor/posteditorbackend.h"
-#include "poll.h"
-#include "post.h"
-#include <KLocalizedString>
-#include <QtMath>
-#include <qvariant.h>
+
+#include "abstractaccount.h"
+#include "attachmenteditormodel.h"
+#include "posteditorbackend.h"
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -270,4 +265,6 @@ void AbstractTimelineModel::actionDelete(const QModelIndex &index, Post *post)
 {
     Q_UNUSED(index);
     m_account->deleteResource(m_account->apiUrl(QStringLiteral("/api/v1/statuses/%1").arg(post->postId())), true, this, {});
-}
\ No newline at end of file
+}
+
+#include "moc_abstracttimelinemodel.cpp"
\ No newline at end of file
