@@ -3,8 +3,6 @@
 
 #pragma once
 
-#include <QtQml/qqmlregistration.h>
-
 #include "timelinemodel.h"
 
 class AbstractAccount;
@@ -71,6 +69,9 @@ Q_SIGNALS:
     void filtersChanged();
     void tabChanged();
 
+protected:
+    void reset() override;
+
 private:
     void updateRelationships();
     void updateTabFilters();
