@@ -3,8 +3,6 @@
 
 #pragma once
 
-#include <QtQml/qqmlregistration.h>
-
 #include "timelinemodel.h"
 
 class AbstractAccount;
@@ -17,6 +15,7 @@ class MainTimelineModel : public TimelineModel
     QML_ELEMENT
 
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
+    Q_PROPERTY(QString listId READ listId WRITE setListId NOTIFY listIdChanged)
     Q_PROPERTY(bool atEnd READ atEnd NOTIFY atEndChanged)
 
 public:
@@ -27,18 +26,29 @@ public:
     QString name() const;
 
     /// Set the name of the timeline to fetch ("home", "public" or "federated")
+    /// \p name Can be "home", "public", "federated", "bookmarks", "favourites", "trending" or "list"
     void setName(const QString &name);
 
+    /// Name of the list id
+    QString listId() const;
+
+    /// Set the name of the list to view, only works if name is set to "list"
+    void setListId(const QString &id);
+
     void fillTimeline(const QString &fromId) override;
     QString displayName() const override;
     void handleEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload) override;
 
     bool atEnd() const;
 
+    void reset() override;
+
 Q_SIGNALS:
     void atEndChanged();
+    void listIdChanged();
 
 private:
     QString m_timelineName;
+    QString m_listId;
     QUrl m_next;
 };
