@@ -3,8 +3,6 @@
 
 #pragma once
 
-#include <QtQml/qqmlregistration.h>
-
 #include "timelinemodel.h"
 
 /// Model used for fetching posts for a specific tag (like searching for #KDE)
@@ -32,6 +30,8 @@ public:
     /// \see hashtag
     void setHashtag(const QString &hashtag);
 
+    void reset() override;
+
 Q_SIGNALS:
     /// Emitted if the hashtag is changed
     /// \see setHashtag
